@@ -3,7 +3,7 @@ use strict;
 use warnings;
 BEGIN{
 	our $VERSION;
-	$VERSION='0.98' unless $INC{'Storable/AMF0.pm'};
+	$VERSION='0.99' unless $INC{'Storable/AMF0.pm'};
 }
 use Storable::AMF0; # install and create all methods
 use Exporter 'import';
@@ -16,7 +16,7 @@ our %EXPORT_TAGS = (
 		  new_date
 		  parse_serializator_option
 		  parse_option
-		  freeze0 freeze3 thaw0 thaw3
+		  freeze0 freeze3 thaw0 thaw3 thaw0_sv
 		  deparse_amf0 deparse_amf3
           )
     ]
